Device class

Device Model

Represents a device in the KOMBU IoT System

Constructors

Device({required String id, required String deviceId, required String userId, required String deviceName, String? deviceType, String? location, String? status, String? firmwareVersion, String? latestFirmwareVersion, String? hardwareVersion, String? iotThingArn, bool? wifiConnected, String? bleAddress, DateTime? lastSeen, required DateTime createdAt, required DateTime updatedAt, String? owner})
Device.fromJson(Map<String, dynamic> json)
factory

Properties

bleAddress String?
final
createdAt DateTime
final
deviceId String
final
deviceName String
final
deviceType String?
final
firmwareVersion String?
final
hardwareVersion String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
iotThingArn String?
final
lastSeen DateTime?
final
latestFirmwareVersion String?
final
location String?
final
owner String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
updatedAt DateTime
final
userId String
final
wifiConnected bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited