DeviceTokenQueries class
GraphQL Queries for DeviceToken Model
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- getDeviceToken → const String
- Get device token by ID
- listDeviceTokens → const String
- List device tokens for a user
- tokensByUser → const String
- Query device tokens by user ID