DeviceUserMappingQueries class

GraphQL Queries for DeviceUserMapping Model

Constructors

DeviceUserMappingQueries()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

devicesByUser → const String
Query all devices for a user
getDeviceUserMapping → const String
Get device-user mapping by ID
listDeviceUserMappings → const String
List all device-user mappings
mappingByDeviceAndUser → const String
Query mapping by deviceId and userId (check if user has access to device)
usersByDevice → const String
Query all users for a device