PushCommandHelper class

Push Command Helper Class

Provides easy-to-use methods for pushing commands to IoT devices

Constructors

PushCommandHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pushCommand({required String topic, required dynamic payload}) Future<PushCommandResponse>
Push command using helper method (recommended)
pushCommandRaw({required String topic, required String payload}) Future<GraphQLResponse<String>>
Push command using raw GraphQL mutation (advanced usage)